@@ -18,7 +18,7 @@ sys.path.insert(0, rootdir)
 # -- Project information -----------------------------------------------------
 # https://www.sphinx-doc.org/en/master/usage/configuration.html#project-information
 
-project = 'ctakesclient'
+project = "ctakesclient"
 copyright = "2022, Boston Children's Hospital"
 author = "Boston Children's Hospital"
 
@@ -26,17 +26,17 @@ author = "Boston Children's Hospital"
 # https://www.sphinx-doc.org/en/master/usage/configuration.html#general-configuration
 
 extensions = [
-    'myst_parser',
-    'sphinx.ext.autodoc',
-    'sphinx_rtd_theme',
+    "myst_parser",
+    "sphinx.ext.autodoc",
+    "sphinx_rtd_theme",
 ]
 
-templates_path = ['_templates']
-exclude_patterns = ['_build', 'Thumbs.db', '.DS_Store']
+templates_path = ["_templates"]
+exclude_patterns = ["_build", "Thumbs.db", ".DS_Store"]
 
 
 # -- Options for HTML output -------------------------------------------------
 # https://www.sphinx-doc.org/en/master/usage/configuration.html#options-for-html-output
 
-html_theme = 'sphinx_rtd_theme'
-html_static_path = ['_static']
+html_theme = "sphinx_rtd_theme"
+html_static_path = ["_static"]
